@@ -3,6 +3,9 @@ package  Novel::Robot::Parser;
 use Moo;
 use Novel::Robot::Parser::Jjwxc;
 use Novel::Robot::Parser::Dddbbb;
+use Novel::Robot::Parser::TXT;
+
+our $VERSION = 0.06;
 
 sub init_parser {
     my ( $self, $site ) = @_;
